@@ -9,16 +9,12 @@ from lambda_actor.types.type_actor_message import *
 
 logger = logging.getLogger()
 
-def clear_all_q(bucket: str, prefix: str, filename: str):
+def clear_all_q(bucket: str, prefix: str, actor_conf_file: str):
     """
     """
     s3_client = boto3.client('s3')
-    actor_conf = ActorConf.get_actor_conf(s3_client=s3_client, bucket=bucket, prefix=prefix, filename=filename)
+    actor_conf = ActorConf.get_actor_conf(s3_client=s3_client, bucket=bucket, prefix=prefix, actor_conf_file=actor_conf_file)
 
-    trigger_input_path = f"{actor_conf.trigger_file_prefix}/{actor_conf.trigger_file}"
-    tmp_trigger_input_path = f"/tmp/{actor_conf.trigger_file}"
-    logger.info(f"trigger_input_path: {trigger_input_path}")
-    logger.info(f"tmp_trigger_input_path: {tmp_trigger_input_path}")
     logger.info(f"actor_conf: {actor_conf}")
 
     sqs = boto3.resource('sqs', region_name='ap-northeast-1')
